@@ -37,17 +37,24 @@ class Phantom(object):
             # return sbp.check_output(cmd)
             self.logger.error(errors)
             if output:
-                return output.decode('utf-8')
+                # return output.decode('utf-8')
+                res = output.decode('utf-8')
+                if res.startswith('E: Phantomjs failed to open page'):
+                    self.logger.error(res)
+                    res = ''
+                return res
             # import sys
             # print(sys.stdout.encoding)
             # proc = sbp.run(cmd, stdout=sbp.PIPE, encoding='utf-8', timeout=self.process_timeout)
             # return proc.stdout
-        except sbp.CalledProcessError as e:
+        except sbp.CalledProcessError:
             self.logger.exception("E: PhantomJS command failed")
+        except:
+            self.logger.exception("E: Unknown PhantomJS error")
         return ''
 
-    def download_page(self, conf, proxy='', proxy_type='', js_path='', ssl_verify=True, load_images=False,
-                      cookie_file=False):
+    def download_page(self, conf, proxy='', proxy_type='', js_path='', ssl_verify=True,
+                      load_images=False, cookies_file=''):
         confs = json.dumps(conf)
 
         cmd = [self.exec_path]
@@ -62,8 +69,8 @@ class Phantom(object):
             cmd.append("--proxy-type=%s" % (proxy_type,))
         if proxy:
             cmd.append("--proxy=%s" % (proxy,))
-        if cookie_file:
-            cmd.append("--cookies-file=%s" % (cookie_file,))
+        if cookies_file:
+            cmd.append("--cookies-file=%s" % (cookies_file,))
 
         if not js_path:
             cmd.extend([os.path.join(os.path.dirname(__file__), 'get_source_wait_for.js'), confs])
