@@ -52,12 +52,14 @@ void Utils::messageHandler(QtMsgType type, const char *msg)
     QDateTime now = QDateTime::currentDateTime();
 
     switch (type) {
+#ifndef QT_NO_DEBUG
     case QtDebugMsg:
         fprintf(stdout, "%s [DEBUG] %s\n", qPrintable(now.toString(Qt::ISODate)), msg);
         break;
     case QtWarningMsg:
         fprintf(stderr, "%s [WARNING] %s\n", qPrintable(now.toString(Qt::ISODate)), msg);
         break;
+#endif
     case QtCriticalMsg:
         fprintf(stderr, "%s [CRITICAL] %s\n", qPrintable(now.toString(Qt::ISODate)), msg);
         break;
